'use strict';

const { Gdk, GObject, Gtk, St } = imports.gi;
const PopupMenu = imports.ui.popupMenu;

const ExtensionUtils = imports.misc.extensionUtils;
const Me = ExtensionUtils.getCurrentExtension();

const Me_PopupMenu = Me.imports.modules.popupMenu;

const Docker = Me.imports.lib.docker;
const Tooltip = Me.imports.lib.tooltip;

var Container_Menu = GObject.registerClass(
	class Container_Menu extends Me_PopupMenu.PopupSubMenuMenuItem {
		_init(container) {
			super._init(container.name);
			this._container = container;
			this._compose_label = ` (${container.compose_project})`;
			this._set_state();
			this._set_docker_compose();
		}

		_set_docker_compose() {
			if (this._container.compose_dir) {
				this._icon = new St.Icon({
					icon_name: 'media-record-symbolic',
					style_class: 'compose',
					icon_size: '14'
				});
				this.actor.insert_child_at_index(this._icon, 2);
			}
		}

		_set_state() {
			this._icon = new St.Icon({
				icon_name: 'media-record-symbolic',
				style_class: 'stop',
				icon_size: '14'
			});

			if (this._container.state == "running") {
				this._icon.style_class = 'running';
			}

			this.actor.insert_child_at_index(this._icon, 1);
		}

		add_ports() {
			if (!this._container.settings.get_boolean('show-ports') ||
				this._container.state !== "running") {
				return;
			}

			if (!Object.keys(this._container.ports).length) {
				return;
			}

			this.menu.addMenuItem(new PopupMenu.PopupSeparatorMenuItem(_("Ports")));

			for (let key of Object.keys(this._container.ports)) {
				let port = key.split("/")[0];
				let by_ip = `${this._container.ip}:${port}`;
				this[by_ip] = new PopupMenu.PopupMenuItem(`${port} -> ${by_ip}`);
				this[by_ip].connect('activate', () => {
					// Open in browser
					let url = `http://${by_ip}`;
					Gtk.show_uri(null, url, Gdk.CURRENT_TIME);
				});

				this.menu.addMenuItem(this[by_ip]);

				if (this._container.ports[key][0].HostPort) {
					let host_port = this._container.ports[key][0].HostPort;
					let by_localhost = `localhost:${host_port}`;
					this[by_localhost] = new PopupMenu.PopupMenuItem(`${port} -> ${by_localhost}`);
					this[by_localhost].connect('activate', () => {
						// Open in browser
						let url = `http://${by_localhost}`;
						Gtk.show_uri(null, url, Gdk.CURRENT_TIME);
					});

					this.menu.addMenuItem(this[by_localhost]);
				}
			}
		}
	}
)